@@ -3,6 +3,10 @@ import RockPaperScissorsFullGame.RPS as RPS
 
 
 def main():
+    #first ask user if they want to see ascii art
+    asciiVisibility = RPS.setAsciiVisibility()
+    
+    # game
     play = True
     while (play):
         computerItem = RPS.getComputerItem()
@@ -16,7 +20,13 @@ def main():
                 print("Invalid Input\n")
                 continue
             else:
-                print("You choose " + playerItem.name + ". Computer chooses " + computerItem.name + ".")
+                playerMove = RPS.getPlayerAsciiArt(playerItem)
+                computerMove = RPS.getComputerAsciiArt(computerItem)
+                if(not asciiVisibility):
+                    print("You choose " + playerItem.name + ". Computer chooses " + computerItem.name + ".")
+                else:
+                    print("Player Move: " + playerItem.name + playerMove)
+                    print("Computer Move: " + computerItem.name + computerMove)
                 result = RPS.getOutcome(playerItem,computerItem)
                 print("You " + result.name + ".\n")
 
